aboutsummaryrefslogtreecommitdiffstats
path: root/remove_stale.pl
diff options
context:
space:
mode:
authorJosip Rodin <joy>2001-07-31 19:31:24 +0000
committerJosip Rodin <joy>2001-07-31 19:31:24 +0000
commit001ac536478c7dc9e3e3fd1247e29e9845dca445 (patch)
tree20a8532ecb383eff2e7bd8e635f17fd046b59611 /remove_stale.pl
parented47e8b7ea8185a2aea8d1f9851d5459ee6093dc (diff)
added an exception for international/french
CVS version numbers remove_stale.pl: 1.5 -> 1.6
Diffstat (limited to 'remove_stale.pl')
-rwxr-xr-xremove_stale.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/remove_stale.pl b/remove_stale.pl
index 15b78af2ae3..bdf78cbe68e 100755
--- a/remove_stale.pl
+++ b/remove_stale.pl
@@ -39,8 +39,8 @@ sub recurse
# Get parameter.
my $directory = shift;
- # Don't try to do anything in the WNPP and l10n directories.
- return 0 if $directory =~ /wnpp$/ or $directory =~ /l10n$/;
+ # Don't try to do anything in the WNPP, l10n or intl/french directories.
+ return 0 if $directory =~ /wnpp$/ or $directory =~ /l10n$/ or $directory =~ /ional/french$/;
# Load all entries for this directory.
opendir THISDIR, $directory

© 2014-2024 Faster IT GmbH | imprint | privacy policy